* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces)
  * Virtual Workspaces Configuration
